@@ -3,6 +3,7 @@ import boto3
 from botocore.exceptions import ClientError
 from abc import abstractmethod, ABC
 import logging
+import os
 
 
 class Scraper(ABC):
@@ -56,7 +57,9 @@ class Scraper(ABC):
         self.to_parquet(local_file_name, dataset_index)
         try:
             s3.upload_file(local_file_name, bucket_name, file_name)
+            os.remove(local_file_name)
         except ClientError as e:
             logging.error(e)
+            os.remove(local_file_name)
             return False
         return True
\ No newline at end of file
