@@ -204,22 +204,22 @@ class InstagramScraper(Scraper):
         if 'followers' in self.output_datasets:
             for account in tmp_list_profiles:
                 followers_data = self.query_followers(self.cookies, account['twitter_internal_id'])
-                tmp_list_followers += {'account':account['username'], 'followers':list(followers_data)}
+                tmp_list_followers.append({'account':account['username'], 'followers':list(followers_data)})
             self.output_datasets['followers'] = self.output_datasets['followers'].append(tmp_list_followers, ignore_index=True)
         if 'following' in self.output_datasets:
             for account in tmp_list_profiles:
                 following_data = self.query_followings(self.cookies, account['twitter_internal_id'])
-                tmp_list_following += {'account':account['username'], 'following':list(following_data)}
+                tmp_list_following.append({'account':account['username'], 'following':list(following_data)})
             self.output_datasets['following'] = self.output_datasets['following'].append(tmp_list_following, ignore_index=True)
         if 'commenters' in self.output_datasets:
             for post in tmp_list_posts:
                 commenters_data = self.query_posts_commenters(self.cookies, post['short_code'])
-                tmp_list_commenters += {'username': post['username'], 'post_short_code':post['short_code'], 'commenters':list(commenters_data)}
+                tmp_list_commenters.append({'username': post['username'], 'post_short_code':post['short_code'], 'commenters':list(commenters_data)})
             self.output_datasets['commenters'] = self.output_datasets['commenters'].append(tmp_list_commenters, ignore_index=True)
         if 'likers' in self.output_datasets:
             for post in tmp_list_posts:
                 likers_data = self.query_posts_likers(self.cookies, post['short_code'])
-                tmp_list_likers += {'username': post['username'], 'post_short_code':post['short_code'], 'likers':list(likers_data)}
+                tmp_list_likers.append({'username': post['username'], 'post_short_code':post['short_code'], 'likers':list(likers_data)})
             self.output_datasets['likers'] = self.output_datasets['likers'].append(tmp_list_likers, ignore_index=True)
 
 
